@@ -18,12 +18,13 @@ class NginxToDatabase:
     def process(self, origin_servers: List[Server], destination_server: Server):
         try:
             for remote_server in origin_servers:
-                SynchronizeRemoteNginxLogsWithLocalRepository().process(remote_server, destination_server)
-                raw_data = ReadAllLogsFileIntoMemoryUsingPandas(self.data_processor).process(destination_server)
-                normalized_data = NormalizeModelData(self.data_processor).process(raw_data, remote_server.name)
-                clean_data = EliminateUnnecessaryData(self.data_processor, remote_server).process(normalized_data)
+                # SynchronizeRemoteNginxLogsWithLocalRepository().process(remote_server, destination_server)
+                raw_data = ReadAllLogsFileIntoMemoryUsingPandas(self.data_processor)\
+                    .process(destination_server, remote_server, self.database)
+                # normalized_data = NormalizeModelData(self.data_processor).process(raw_data, remote_server.name)
+                # clean_data = EliminateUnnecessaryData(self.data_processor, remote_server).process(normalized_data)
                 # clean_data = normalized_data
-                PersistIntoDatabase(self.database, remote_server).process(clean_data)
+                # PersistIntoDatabase(self.database, remote_server).process(clean_data)
 
                 # InformProcessExecutionStatus(SucessMessage())
                 # print(clean_data.info())
